@@ -29,17 +29,17 @@ export INSTPATH="/home/user/img-install"
 export TARPATH="$SDCARD"
 export DLURL="http://qole.org/files"
 #This doesn't work:
-#export BZ2CMD1="bzcat"
-#export BZ2CMD2="| tar xf -"
 export GZCMD1="tar -xzf"
 
 export EXTPATH1=$TARPATH
 export PKGNAME1="EASY DEBIAN IMAGE FILE"
 export BIGTAR1="debian-m5-v2.img.ext2.bz2"
 export BIGIMG1="debian-m5-v2.img.ext2"
-export BZ2CMD1="bzip2 -dc "
-export BZ2CMD2=" > $TARPATH/$BIGIMG1"
-export TARCMD1="$BZ2CMD1 $TARPATH/$BIGTAR1 $BZ2CMD2"
+# export BZ2CMD1="bzip2 -d "
+# export BZ2CMD2=" > $TARPATH/$BIGIMG1"
+# export BZ2CMD1="cat "
+# export BZ2CMD2=" | bunzip2 > "
+# export TARCMD1="cat $TARPATH/$BIGTAR1 | bunzip2 > $TARPATH/$BIGIMG1"
 export MD51="1c02d35d6453fd35390ae025bd930ba2"
 export EXTCMD1=""
 
@@ -101,13 +101,15 @@ do
      cd $EXTPATH1
      echo Extracting the image file. This will take some time.
 
-     TARERR=`$TARCMD1 2>&1`
-     # TARERR="unspecified bzip2 error"
      # echo $TARCMD1
-     $BZ2CMD1 $TARPATH/$BIGTAR1 
-     # > $TARPATH/$BIGIMG1
+     # echo 'cat $TARPATH/$BIGTAR1 | bunzip2 > $TARPATH/$BIGIMG1'
+     # TARERR=`$TARCMD1 2>&1`
+     TARERR="Unknown bzip2 error"
+     # read -p 'press enter' key
+     #$TARCMD1
+     cat $TARPATH/$BIGTAR1 | bunzip2 > $TARPATH/$BIGIMG1
      if [ "$?" = 0 ] ; then
-	 # rm -rf $TARPATH/$BIGTAR1
+	 rm -rf $TARPATH/$BIGTAR1
          $EXTCMD1
          export MSG1=`printf "CONGRATULATIONS!\n\nAll has gone well!\n\nSuccess installing $PKGNAME1 package!"`
          gxmessage -center -alignbuttons right -buttons GTK_STOCK_OK:0 -geometry 640x250 -title "SUCCESS!" "$MSG1"
